@@ -159,8 +159,8 @@ class Template(BaseModel):
     ARMM: Optional[NoneInt] = ARMM
     RRSP: str = RRSP
     DRSP: str = DRSP
-    CUSD: Optional[bool] = CUSD
-    ADOW: Optional[bool] = ADOW
+    CUSD: Optional[Union[int, bool]] = CUSD
+    ADOW: Optional[Union[int, bool]] = ADOW
     CMNT: Optional[str] = CMNT
 
     class Config:
@@ -249,4 +249,4 @@ class CustomerExtensionExtended(BaseModel):
     Message: Optional[str] = Message
     FILE: str = FILE
     PK01: Optional[str] = PK01
-    CHB1: Optional[bool] = CHB1
\ No newline at end of file
+    CHB1: Optional[Union[int, bool]] = CHB1
\ No newline at end of file
